@@ -9,92 +9,19 @@ from rest_framework.views import APIView
 from common.rest_extend.views.views import Select, BaseView
 
 
-class RelatedView(BaseView):
-    CHOOSE_GROUP = "choosegroup"
-    RESERVED_FIELD = deepcopy(Select.RESERVED_FIELD) + [CHOOSE_GROUP]
-    FORBID_VALUES = dict(**Select.FORBID_VALUES, **{CHOOSE_GROUP: ["password"]})
+class InjectionData():
+    def related_data(self, method):
+        related_obj = None
+        related_mapping = None
+        return related_obj, related_mapping
 
-    @related_vaild_legal_decorator
-    def get(
-            self,
-            request,
-            obj,
-            obj_serializer,
-            data=None,
-            need_results=False,
-            need_queryset=False,
-            keys=None,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
-            related_mapping: dict = None,
-            m_to_m_mapping: dict = None,
-            **kwargs,
-    ):
-        """
-        扩展返回字段（关联表）
-        1、获取queryset
-        2、扩展字段
-        :param request:
-        :param obj:
-        :param obj_serializer:
-        :param obj_relevance: 外键关联对象
-        :param mapping: 需要扩展字段对应的映射
-        :return:
-        """
-        results, queryset, current_page_queryset = self.find(obj, request.GET.dict(), obj_serializer)
+    def m_to_m_data(self, method):
+        m_to__obj = None
+        m_to__mapping = None
+        return m_to__obj, m_to__mapping
 
-        try:
-            if not related_obj:
-                related_obj, related_mapping = self.injection_related_data('GET')
-            if not m_to_m_obj:
-                m_to_m_obj, m_to_m_mapping = self.injection_m_to_m_data('GET')
-            if results.data and results.data.result and related_mapping and related_obj:
-                result = self.extend_result_field(
-                    obj_serializer, related_obj, m_to_m_obj, related_mapping, m_to_m_mapping, current_page_queryset
-                )
-                results.data.result = result
-        except Exception as e:
-            get_error_status_code(e, results)
-        if need_results:
-            return results
-        return RESTResponse(results)
 
-    def post(
-            self,
-            request,
-            obj,
-            obj_serializer,
-            data=None,
-            need_results=False,
-            related_obj: list = None,
-            m_to_m_obj: list = None,
-            related_mapping=None,
-            m_to_m_mapping=None,
-            **kwargs,
-    ):
-        results = Results()
-        if not data:
-            data = request.data
-        if data.get("data"):
-            data = data.get("data")
-        serializer = obj_serializer(data=data)
-        if not related_obj:
-            related_obj, related_mapping = self.injection_related_data('POST')
-        if not m_to_m_obj:
-            m_to_m_obj, m_to_m_mapping = self.injection_m_to_m_data('POST')
-        self.execute_related_extend(related_obj, related_mapping, data)
-        self.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
-        try:
-            valid = serializer.is_valid(raise_exception=True)
-            serializer.save()
-            results.describe = "add  successfully！！！"
-            results.status = SUCCESS
-            results.code = 200
-        except Exception as e:
-            results.code, results.describe = get_error_status_code(e)
-        if need_results:
-            return results
-        return RESTResponse(results)
+class Related(Select):
 
     def execute_related_extend(self, related_obj, related_mapping, data):
         if related_obj and related_mapping:
@@ -185,6 +112,99 @@ class RelatedView(BaseView):
                 else:
                     item_result[key] = None
 
+    def get_queryset(self, obj, data) -> (QuerySet, QuerySet):
+        pass
+
+
+class RelatedView(BaseView):
+    relate = Related()
+    injection_data = InjectionData()
+    CHOOSE_GROUP = "choosegroup"
+    RESERVED_FIELD = deepcopy(Select.RESERVED_FIELD) + [CHOOSE_GROUP]
+    FORBID_VALUES = dict(**Select.FORBID_VALUES, **{CHOOSE_GROUP: ["password"]})
+
+    @related_vaild_legal_decorator
+    def get(
+            self,
+            request,
+            obj,
+            obj_serializer,
+            data=None,
+            need_results=False,
+            need_queryset=False,
+            keys=None,
+            related_obj: list = None,
+            m_to_m_obj: list = None,
+            related_mapping: dict = None,
+            m_to_m_mapping: dict = None,
+            **kwargs,
+    ):
+        """
+        扩展返回字段（关联表）
+        1、获取queryset
+        2、扩展字段
+        :param request:
+        :param obj:
+        :param obj_serializer:
+        :param obj_relevance: 外键关联对象
+        :param mapping: 需要扩展字段对应的映射
+        :return:
+        """
+        results, queryset, current_page_queryset = self.find(obj, request.GET.dict(), obj_serializer)
+
+        try:
+            if not related_obj:
+                related_obj, related_mapping = self.injection_data.related_data('GET')
+            if not m_to_m_obj:
+                m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data('GET')
+            if results.data and results.data.result and related_mapping and related_obj:
+                result = self.relate.extend_result_field(
+                    obj_serializer, related_obj, m_to_m_obj, related_mapping, m_to_m_mapping, current_page_queryset
+                )
+                results.data.result = result
+        except Exception as e:
+            get_error_status_code(e, results)
+        if need_results:
+            return results
+        return RESTResponse(results)
+
+    def post(
+            self,
+            request,
+            obj,
+            obj_serializer,
+            data=None,
+            need_results=False,
+            related_obj: list = None,
+            m_to_m_obj: list = None,
+            related_mapping=None,
+            m_to_m_mapping=None,
+            **kwargs,
+    ):
+        results = Results()
+        if not data:
+            data = request.data
+        if data.get("data"):
+            data = data.get("data")
+        serializer = obj_serializer(data=data)
+        if not related_obj:
+            related_obj, related_mapping = self.injection_data.related_data('POST')
+        if not m_to_m_obj:
+            m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data('POST')
+        self.relate.execute_related_extend(related_obj, related_mapping, data)
+        self.relate.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
+        try:
+            valid = serializer.is_valid(raise_exception=True)
+            serializer.save()
+            results.describe = "add  successfully！！！"
+            results.status = SUCCESS
+            results.code = 200
+        except Exception as e:
+            results.code, results.describe = get_error_status_code(e)
+        if need_results:
+            return results
+        return RESTResponse(results)
+
     def get_queryset(self, obj, data) -> (QuerySet, QuerySet):
 
         drop_group = data.get(self.CHOOSE_GROUP)
@@ -197,13 +217,3 @@ class RelatedView(BaseView):
     def extend_page_type_results(self, data, page_type_results, extend_queryset, *args, **kwargs):
         if extend_queryset:
             page_type_results.group = list(extend_queryset)
-
-    def injection_related_data(self, method):
-        related_obj = None
-        related_mapping = None
-        return related_obj, related_mapping
-
-    def injection_m_to_m_data(self, method):
-        m_to__obj = None
-        m_to__mapping = None
-        return m_to__obj, m_to__mapping
